/****************************************************************************
** Meta object code from reading C++ file 'seatsmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/seat/seatsmanager.h"
#include "private/wserver_p.h"
#include <wsurface.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'seatsmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12SeatsManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto SeatsManager::qt_create_metaobjectdata<qt_meta_tag_ZN12SeatsManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SeatsManager",
        "seatAdded",
        "",
        "WSeat*",
        "seat",
        "seatRemoved",
        "deviceReassigned",
        "WInputDevice*",
        "device",
        "oldSeat",
        "newSeat",
        "deviceAdded",
        "deviceRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'seatAdded'
        QtMocHelpers::SignalData<void(WSeat *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'seatRemoved'
        QtMocHelpers::SignalData<void(WSeat *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'deviceReassigned'
        QtMocHelpers::SignalData<void(WInputDevice *, WSeat *, WSeat *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 3, 9 }, { 0x80000000 | 3, 10 },
        }}),
        // Signal 'deviceAdded'
        QtMocHelpers::SignalData<void(WInputDevice *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'deviceRemoved'
        QtMocHelpers::SignalData<void(WInputDevice *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SeatsManager, qt_meta_tag_ZN12SeatsManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SeatsManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SeatsManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SeatsManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12SeatsManagerE_t>.metaTypes,
    nullptr
} };

void SeatsManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SeatsManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->seatAdded((*reinterpret_cast<std::add_pointer_t<WSeat*>>(_a[1]))); break;
        case 1: _t->seatRemoved((*reinterpret_cast<std::add_pointer_t<WSeat*>>(_a[1]))); break;
        case 2: _t->deviceReassigned((*reinterpret_cast<std::add_pointer_t<WInputDevice*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<WSeat*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<WSeat*>>(_a[3]))); break;
        case 3: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<WInputDevice*>>(_a[1]))); break;
        case 4: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<WInputDevice*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< WSeat* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< WSeat* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< WSeat* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SeatsManager::*)(WSeat * )>(_a, &SeatsManager::seatAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SeatsManager::*)(WSeat * )>(_a, &SeatsManager::seatRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SeatsManager::*)(WInputDevice * , WSeat * , WSeat * )>(_a, &SeatsManager::deviceReassigned, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SeatsManager::*)(WInputDevice * )>(_a, &SeatsManager::deviceAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SeatsManager::*)(WInputDevice * )>(_a, &SeatsManager::deviceRemoved, 4))
            return;
    }
}

const QMetaObject *SeatsManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SeatsManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SeatsManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SeatsManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void SeatsManager::seatAdded(WSeat * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void SeatsManager::seatRemoved(WSeat * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void SeatsManager::deviceReassigned(WInputDevice * _t1, WSeat * _t2, WSeat * _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void SeatsManager::deviceAdded(WInputDevice * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void SeatsManager::deviceRemoved(WInputDevice * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
